@@ -6,10 +6,10 @@ use log::*;
 use rand::{thread_rng, Rng};
 use rayon::prelude::*;
 use solana_client::thin_client::create_client;
+use solana_core::consensus::VOTE_THRESHOLD_DEPTH;
 use solana_core::validator::ValidatorExit;
-use solana_core::{
-    cluster_info::VALIDATOR_PORT_RANGE, consensus::VOTE_THRESHOLD_DEPTH, contact_info::ContactInfo,
-    gossip_service::discover_cluster,
+use solana_gossip::{
+    cluster_info::VALIDATOR_PORT_RANGE, contact_info::ContactInfo, gossip_service::discover_cluster,
 };
 use solana_ledger::{
     blockstore::Blockstore,
@@ -289,7 +289,10 @@ pub fn check_for_new_roots(num_new_roots: usize, contact_infos: &[ContactInfo],
             let min_node = roots.iter().map(|r| r.len()).min().unwrap_or(0);
             done = min_node >= num_new_roots;
             if done || last_print.elapsed().as_secs() > 3 {
-                info!("{} min observed roots {}/16", test_name, min_node);
+                info!(
+                    "{} {} min observed roots {}/16",
+                    test_name, ingress_node.id, min_node
+                );
                 last_print = Instant::now();
             }
         }
@@ -381,7 +384,7 @@ fn get_and_verify_slot_entries(
     last_entry: &Hash,
 ) -> Vec<Entry> {
     let entries = blockstore.get_slot_entries(slot, 0).unwrap();
-    assert_eq!(entries.verify(last_entry), true);
+    assert!(entries.verify(last_entry));
     entries
 }
 
